@@ -130,38 +130,54 @@ class MyWhatify:
 
     @classmethod
     def get_magento(cls, table: str = None, page: str = None, limit: str = None, add_total: str = None,
-                    only_total: str = None):
+                    only_total: str = None, get_df: bool=True):
         '''
         GET magento store api
         :param table: the specific table
         :param page: the page number
         :param limit: the page limit
-        :param add_total:
-        :param only_total:
+        :param add_total: add total rows count of table in return json
+        :param only_total: return only total row count in table
+        :param get_df: change the return json into DataFrame
         :return:
         '''
         return cls.magento_api(api_method='GET', table=table, page=page, limit=limit, addtotal=add_total,
-                               onlytotal=only_total)
+                               onlytotal=only_total, get_df=get_df)
 
     @classmethod
     def post_magento(cls, body: str = None, table: str = None, page: str = None, limit: str = None,
-                     add_total: str = None, only_total: str = None):
+                     add_total: str = None, only_total: str = None, get_df: bool=True):
         '''
         POST magento store api
         :param body:
         :param table: the specific table
         :param page: the page number
         :param limit: the page limit
-        :param add_total:
-        :param only_total:
+        :param add_total: add total rows count of table in return json
+        :param only_total: return only total row count in table
+        :param get_df: change the return json into DataFrame
         :return:
         '''
         return cls.magento_api(api_method='POST', body=body, table=table, page=page, limit=limit, addtotal=add_total,
-                               onlytotal=only_total)
+                               onlytotal=only_total, get_df=get_df)
+
+    @classmethod
+    def get_magento_table_count(cls, table: str = None):
+        '''
+        GET magento table count
+        :param table: the specific table
+        :return: the table count
+        '''
+        retval = None
+        try:
+            retval = cls.magento_api(api_method='GET', table=table, onlytotal=True, get_df=False)['data']['total']
+        except Exception as ex:
+            logging.info('Failed to get table count, got error: ' + str(ex))
+        return retval
 
     @classmethod
     def magento_api(cls, api_method: str, body: str = None, table: str = None, page: str = None,
-                    limit: str = None, addtotal: str = None, onlytotal: str = None):
+                    limit: str = None, addtotal: str = None, onlytotal: str = None, get_df: bool=True):
         '''
         magento store api with params in query
         :param api_method: set the relevant method GET/POST... MANDATORY
@@ -169,11 +185,11 @@ class MyWhatify:
         :param table: the specific table
         :param page: the page number
         :param limit: the page limit
-        :param add_total:
-        :param only_total:
+        :param addtotal: add total rows count of table in return json
+        :param onlytotal: return only total row count in table
+        :param get_df: change the return json into DataFrame
         :return:
         '''
-        ret_json = None
         retval = None
         base_url = cls.magento_magento2url + '?'
         base_vars = ['table', 'page', 'limit', 'addtotal', 'onlytotal']
@@ -182,12 +198,12 @@ class MyWhatify:
                 base_url += str(var) + '=' + str(locals().get(var)) + '&'
         base_url = base_url[:-1]
         try:
-            ret_json = cls.base_api(url=base_url, method=api_method, headers=cls.magento_headers, body=body)
+            retval = cls.base_api(url=base_url, method=api_method, headers=cls.magento_headers, body=body)
         except Exception as e:
             logging.info('Failed to get data from api, got error: ' + str(e))
-        if ret_json:
+        if retval and get_df:
             try:
-                retval = pd.DataFrame.from_dict(ret_json['data']['rows'], orient='columns')
+                retval = pd.DataFrame.from_dict(retval['data']['rows'], orient='columns')
             except Exception as ex:
                 logging.info('Failed to convert data into DataFrame, got error: ' + str(ex))
         return retval
